## Exploratory Modeling workbench
This is a relatively stable version of the EMA workbench currently under 
development at Delft University of Technology. Documentation can be found 
online: https://emaworkbench.readthedocs.io/en/latest/


[![build status](https://travis-ci.org/quaquel/EMAworkbench.svg?branch=master)](https://travis-ci.org/quaquel/EMAworkbench)
[![Coverage Status](https://coveralls.io/repos/github/quaquel/EMAworkbench/badge.svg?master)](https://coveralls.io/github/quaquel/EMAworkbench?branch=master)
[![Code Health](https://landscape.io/github/quaquel/EMAworkbench/master/landscape.svg?style=flat)](https://landscape.io/github/quaquel/EMAworkbench/master)
[![Documentation Status](https://readthedocs.org/projects/emaworkbench/badge/?version=latest)](http://emaworkbench.readthedocs.org/en/latest/?badge=master)
[![PyPi](https://img.shields.io/pypi/v/ema_workbench.svg)](https://pypi.python.org/pypi/ema_workbench)
[![PyPi](https://img.shields.io/pypi/dm/ema_workbench.svg)](https://pypi.python.org/pypi/ema_workbench)

If you are interested in using the most recent version of the workbench  and
would like to contribute to its further development, contact Jan Kwakkel at 
Delft University of Technology.  

The workbench is available from pip, and is compatible with both Python 2 and
3. For further installation details, see read the docs. 